==> Products.DateRecurringIndex-1.0.tar.gz: Products.DateRecurringIndex-1.0/setup.py <==
# Copyright 2008-2009, BlueDynamics Alliance, Austria - http://bluedynamics.com
# BSD derivative License 

from setuptools import setup, find_packages
import sys, os

version = '1.0'
shortdesc = "Recurring Events, Index for Zope 2 Catalog. Replacement for old DateIndex."
longdesc = open(os.path.join(os.path.dirname(__file__), 'README.txt')).read()
license = open(os.path.join(os.path.dirname(__file__), 'LICENSE.txt')).read()

setup(name='Products.DateRecurringIndex',
      version=version,
      description=shortdesc,
      long_description=longdesc + license,
      classifiers=[
      # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
            'Development Status :: 5 - Production/Stable',
            'Environment :: Web Environment',
            'Framework :: Zope2',
            'License :: OSI Approved :: BSD License',
            'Operating System :: OS Independent',
            'Programming Language :: Python',
            'Topic :: Internet :: WWW/HTTP :: Dynamic Content',            
      ], 
      keywords='zope zope2 index catalog date recurring',
      author='BlueDynamics Alliance',
      author_email='dev@bluedynamics.com',
      url='https://svn.plone.org/svn/collective/Products.DateRecurringIndex',
      license='BSD',
      packages=find_packages('src'),
      package_dir = {'': 'src'},
      namespace_packages=['Products', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'pytz',
          'DateTime>=2.11-dev',
          # Zope 2 dependencies are missing
      ],
      extras_require={
          'test': [
              'interlude',
              # Zope 2 dependencies are missing
          ]
      },      
)

==> Products.DateRecurringIndex-2.0b1.tar.gz: Products.DateRecurringIndex-2.0b1/setup.py <==
from setuptools import setup, find_packages
import os

version = '2.0b1'
shortdesc = "Zope 2 date index with support for recurring events."
longdesc = open('README.rst').read() + "\n\n" +\
           open(os.path.join("docs", "HISTORY.rst")).read()
license = open(os.path.join("docs", "LICENSE.rst")).read()

setup(name='Products.DateRecurringIndex',
      version=version,
      description=shortdesc,
      long_description=longdesc + '\n\n' + license,
      classifiers=[
            'Development Status :: 5 - Production/Stable',
            'Environment :: Web Environment',
            'Framework :: Zope2',
            'License :: OSI Approved :: BSD License',
            'Operating System :: OS Independent',
            'Programming Language :: Python',
            'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
      ],
      keywords='zope zope2 index catalog date recurring',
      author='BlueDynamics Alliance',
      author_email='dev@bluedynamics.com',
      url='https://github.com/collective/Products.DateRecurringIndex',
      license='BSD',
      packages=find_packages('src'),
      package_dir = {'': 'src'},
      namespace_packages=['Products', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
          'ZODB3',
          'Zope2',
          'plone.event',
          'zope.interface',
          'zope.schema',
      ],
      extras_require={
          'test': [
              'interlude',
              'pytz',
              'plone.testing'
          ]},
)
